# Installation

Preferred way to install is as usual (for testing or in isolation):

```bash
$ pipx install gelee
```

For production use (well, ahem, ...) or within a virtual python env:

```bash
$ pip install gelee
```
